@@ -12,26 +12,29 @@ def url_to_module(url):
     if site.endswith('.com.cn'):
         site = site[:-3]
     domain = r1(r'(\.[^.]+\.[^.]+)$', site)
+    if not domain:
+        domain = site
     assert domain, 'unsupported url: ' + url
     
     k = r1(r'([^.]+)', domain)
     downloads = {
+        '56': w56,
+        'acfun': acfun,
+        'bilibili': bilibili,
+        'cntv': cntv,
+        'iask': sina,
+        'iqiyi': iqiyi,
+        'kankanews': bilibili,
+        'ku6': ku6,
+        'pptv': pptv,
+        'sina': sina,
         'sohu': sohu,
         'tudou': tudou,
+        'vimeo': vimeo,
         'yinyuetai': yinyuetai,
         'youku': youku,
         'youtube': youtube,
-        #TODO:
-        # 'acfun': acfun,
-        # 'bilibili': bilibili,
-        # 'kankanews': bilibili,
-        # 'iask': iask,
-        # 'sina': iask,
-        # 'ku6': ku6,
-        # 'pptv': pptv,
-        # 'iqiyi': iqiyi,
-        # '56': w56,
-        # 'cntv': cntv,
+        #TODO
     }
     if k in downloads:
         return downloads[k]
